"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const winston = require("winston");
const LogType_1 = require("./LogType");
class LoggerFactory {
    static getLogger(id) {
        if (!winston.loggers.has(id.toString())) {
            winston.loggers.add(id.toString(), {
                transports: [LoggerFactory.consoleTransport, LoggerFactory.fileTransport(id)],
                format: winston.format.label({ label: id.toString() }),
            });
        }
        return winston.loggers.get(id.toString());
    }
    static logFormatTemplate(i) {
        return `${i.timestamp} ${i.level} [${i.label}] ${i.message}`;
    }
    static getLogFileName(id) {
        switch (id) {
            case LogType_1.LogType.Audit:
                return 'auditLogs.log';
            case LogType_1.LogType.System:
            default:
                return 'logs.log';
        }
    }
}
exports.default = LoggerFactory;
LoggerFactory.consoleTransport = new winston.transports.Console({
    format: winston.format.combine(winston.format.timestamp(), winston.format.cli(), winston.format.printf(LoggerFactory.logFormatTemplate)),
});
LoggerFactory.fileTransport = (id) => new winston.transports.File({
    format: winston.format.combine(winston.format.timestamp(), winston.format.printf(LoggerFactory.logFormatTemplate)),
    options: { flags: 'w' },
    filename: path_1.resolve(LoggerFactory.getLogFileName(id)),
    level: 'info',
});
